@@ -3,8 +3,7 @@ from typing import Dict, Optional
 
 import jax.numpy as jnp
 from chex import dataclass
-
-from .types import Array
+from jaxtyping import f64
 
 
 @dataclass(repr=False)
@@ -15,7 +14,7 @@ class AbstractMeanFunction:
     name: Optional[str] = "Mean function"
 
     @abc.abstractmethod
-    def __call__(self, x: Array) -> Array:
+    def __call__(self, x: f64["N D"]) -> f64["N Q"]:
         """Evaluate the mean function at the given points. This method is required for all subclasses.
 
         Args:
@@ -46,7 +45,7 @@ class Zero(AbstractMeanFunction):
     output_dim: Optional[int] = 1
     name: Optional[str] = "Zero mean function"
 
-    def __call__(self, x: Array, params: dict) -> Array:
+    def __call__(self, x: f64["N D"], params: dict) -> f64["N Q"]:
         """Evaluate the mean function at the given points.
 
         Args:
@@ -75,7 +74,7 @@ class Constant(AbstractMeanFunction):
     output_dim: Optional[int] = 1
     name: Optional[str] = "Constant mean function"
 
-    def __call__(self, x: Array, params: Dict) -> Array:
+    def __call__(self, x: f64["N D"], params: Dict) -> f64["N Q"]:
         """Evaluate the mean function at the given points.
 
         Args:
