@@ -1,14 +1,12 @@
 import typing as tp
-import warnings
 from copy import deepcopy
 
 import jax
 import jax.numpy as jnp
-
-from .types import Array
+from jaxtyping import f64
 
 
-def I(n: int) -> Array:
+def I(n: int) -> f64["N N"]:
     """
     Compute an n x n identity matrix.
     :param n: The size of of the matrix.
@@ -79,22 +77,3 @@ def dict_array_coercion(params: tp.Dict) -> tp.Tuple[tp.Callable, tp.Callable]:
         return jax.tree_util.tree_unflatten(flattened_pytree[1], parameter_array)
 
     return dict_to_array, array_to_dict
-
-
-from functools import wraps
-
-
-def experimental(method):
-    """
-    This is a decorator that can be used to mark a function as experimental.
-    """
-
-    @wraps(method)
-    def wrapper(*args, **kwargs):
-        warnings.warn(
-            "This function is experimental and may give unstable results.",
-            category=UserWarning,
-        )
-        return method(*args, **kwargs)
-
-    return wrapper
